API documentation
=================

This documentation is based on the source code of version |release| of the
`rotate-backups` package. The following modules are available:

.. contents::
   :local:

:mod:`rotate_backups`
---------------------

.. automodule:: rotate_backups
   :members:

:mod:`rotate_backups.cli`
-------------------------

.. automodule:: rotate_backups.cli
   :members:
